@@ -17,6 +17,46 @@ import damo_version
 
 # Core data structures
 
+class OpsAttrs:
+    use_reports = None
+    write_only = None
+    cpus = None         #cpus list string
+
+    def __init__(self, use_reports=False, write_only=False, cpus=None):
+        self.use_reports = _damo_fmt_str.text_to_bool(use_reports)
+        self.write_only = _damo_fmt_str.text_to_bool(write_only)
+        self.cpus = cpus if cpus is not None else 'all'
+
+    def to_str(self, raw):
+        return 'use_reports: %s, write_only: %s, cpus: %s' % (
+                self.use_reports, self.write_only, self.cpus)
+
+    def __str__(self):
+        return self.to_str(False)
+
+    def __eq__(self, other):
+        return type(self) == type(other) and \
+                self.use_reports == other.use_reports and \
+                self.write_only == other.write_only and \
+                self.cpus == other.cpus
+
+    @classmethod
+    def from_kvpairs(cls, kvpairs):
+        use_reports = kvpairs['use_reports'] \
+                if 'use_reports' in kvpiars else False
+        write_only = kvpairs['write_only'] \
+                if 'write_only' in kvpairs else False
+        cpus = kvpairs['cpus'] if 'cpus' in kvpairs else 'all'
+        return OpsAttrs(use_reports=use_reports, write_only=write_only,
+                        cpus=cpus)
+
+    def to_kvpairs(self, raw=False):
+        return collections.OrderedDict([
+            ('use_reports', self.use_reports),
+            ('write_only', self.write_only),
+            ('cpus', self.cpus),
+            ])
+
 class DamonIntervalsGoal:
     access_bp = None
     aggrs = None
@@ -1083,7 +1123,7 @@ class Damos:
             kv['target_nid'] = self.target_nid
         if not omit_defaults or self.access_pattern != DamosAccessPattern():
             kv['access_pattern'] = self.access_pattern.to_kvpairs(raw)
-        kv['apply_interval_us'] = self.apply_interval_us
+        kv['apply_interval_us'] = _damo_fmt_str.format_time_us(self.apply_interval_us, raw)
         if not omit_defaults or self.quotas != DamosQuotas():
             kv['quotas'] = self.quotas.to_kvpairs(raw)
         if not omit_defaults or self.watermarks != DamosWatermarks():
@@ -1110,6 +1150,7 @@ class Damos:
 
 class DamonCtx:
     ops = None
+    ops_attrs = None
     targets = None
     intervals = None
     nr_regions = None
@@ -1117,8 +1158,9 @@ class DamonCtx:
     kdamond = None
 
     def __init__(self, ops='paddr', targets=None, intervals=None,
-                 nr_regions=None, schemes=None):
+                 nr_regions=None, schemes=None, ops_attrs=None):
         self.ops = ops
+        self.ops_attrs = ops_attrs if ops_attrs is not None else OpsAttrs()
         self.targets = targets if targets is not None else []
         for target in self.targets:
             target.context = self
@@ -1131,8 +1173,13 @@ class DamonCtx:
             scheme.context = self
 
     def to_str(self, raw, params_only=False):
-        ops_line = 'ops: %s' % self.ops
-        lines = [ops_line]
+        ops_line_tokens = ['ops: %s' % self.ops]
+        if self.ops_attrs.use_reports:
+            ops_line_tokens.append('use_reports')
+            ops_line_tokens.append('cpus %s' % self.ops_attrs.cpus)
+        if self.ops_attrs.write_only:
+            ops_line_tokens.append('write-only')
+        lines = [' '.join(ops_line_tokens)]
         for idx, target in enumerate(self.targets):
             lines.append('target %d' % idx)
             lines.append(_damo_fmt_str.indent_lines(target.to_str(raw), 4))
@@ -1333,9 +1380,10 @@ features = ['record',       # was in DAMON patchset, but not merged in mainline
             'schemes_filters_active',
                                         # merged in v6.15-rc1
             'schemes_quota_goal_node_mem_used_free',
-                                        # merged in v6.16-rc
-            'schemes_dests',            # merged in mm before v6.16 release
-            'sysfs_refresh_ms',         # merged in mm before v6.16 release
+                                        # merged in v6.16-rc1
+            'schemes_dests',            # merged in v6.17-rc1
+            'sysfs_refresh_ms',         # merged in v6.17-rc1
+            'ops_attrs',                # hacking on damon/next
             ]
 
 _damon_fs = None
@@ -1515,6 +1563,11 @@ def damon_interface():
 def stage_kdamonds(kdamonds):
     return _damon_fs.stage_kdamonds(kdamonds)
 
+def stage_kdamonds_targets(kdamonds):
+    if _damon_fs == _damon_dbgfs:
+        return 'debugfs interface does not support stage_kdamonds_target'
+    return _damon_fs.stage_kdamonds_targets(kdamonds)
+
 def commit_staged(kdamond_idxs):
     if _damon_fs == _damon_dbgfs:
         return 'debugfs interface does not support commit_staged()'
@@ -1525,11 +1578,15 @@ def commit_quota_goals(kdamond_idxs):
         return 'debugfs interface does not support commit_quota_goals()'
     return _damon_fs.commit_quota_goals(kdamond_idxs)
 
-def commit(kdamonds, commit_quota_goals_only=False):
-    if not commit_quota_goals_only:
+def commit(kdamonds, commit_quota_goals_only=False, commit_targets_only=False):
+    if not commit_quota_goals_only and not commit_targets_only:
         err = stage_kdamonds(kdamonds)
         if err:
             return 'staging updates failed (%s)' % err
+    elif commit_targets_only:
+        err = stage_kdamonds_targets(kdamonds)
+        if err:
+            return 'staging target updates failed (%s)' % err
 
     kdamond_idxs = ['%s' % idx for idx, k in enumerate(kdamonds)]
 
