@@ -481,9 +481,27 @@ def damon_ctx_for(args, idx):
     except Exception as e:
         return None, 'invalid nr_regions arguments (%s)' % e
     ops = args.ops[idx]
+    if args.exp_ops_use_reports[idx] is not None:
+        use_reports = args.exp_ops_use_reports[idx]
+    else:
+        use_reports = False
+    if args.exp_ops_write_only[idx] is not None:
+        write_only = args.exp_ops_write_only[idx]
+    else:
+        write_only = False
+    if args.exp_ops_cpus[idx] is not None:
+        cpus = args.exp_ops_cpus[idx]
+    else:
+        cpus = 'all'
+    try:
+        ops_attrs = _damon.OpsAttrs(
+                use_reports=use_reports, write_only=write_only, cpus=cpus)
+    except Exception as e:
+        return None, 'invalid ops_attrs arguments (%s)' % e
 
     try:
-        ctx = _damon.DamonCtx(ops, None, intervals, nr_regions, schemes=[])
+        ctx = _damon.DamonCtx(ops, None, intervals, nr_regions, schemes=[],
+                              ops_attrs=ops_attrs)
         return ctx, None
     except Exception as e:
         return None, 'Creating context from arguments failed (%s)' % e
@@ -515,9 +533,9 @@ def get_nr_targets(args):
 def fillup_none_ctx_args(args):
     nr_ctxs = get_nr_ctxs(args)
     for attr_name in [
-            'ops', 'sample', 'aggr', 'updr', 'minr', 'maxr',
-            'monitoring_intervals', 'monitoring_intervals_goal',
-            'monitoring_nr_regions_range']:
+            'ops', 'exp_ops_use_reports', 'exp_ops_write_only', 'exp_ops_cpus',
+            'sample', 'aggr', 'updr', 'minr', 'maxr', 'monitoring_intervals',
+            'monitoring_intervals_goal', 'monitoring_nr_regions_range']:
         attr_val = getattr(args, attr_name)
         if attr_val is None:
             setattr(args, attr_name, [None] * nr_ctxs)
@@ -853,6 +871,17 @@ def set_monitoring_damos_common_args(parser, hide_help=False):
                         action='append',
                         help='monitoring operations set'
                         if not hide_help else argparse.SUPPRESS)
+    parser.add_argument('--exp_ops_use_reports', action='append',
+                        metavar='<Y|N>',
+                        help='use access reports (experimental)'
+                        if not hide_help else argparse.SUPPRESS)
+    parser.add_argument('--exp_ops_write_only', action='append',
+                        metavar='<Y|N>',
+                        help='monitor writes only (experimental)'
+                        if not hide_help else argparse.SUPPRESS)
+    parser.add_argument('--exp_ops_cpus', action='append', metavar='<cpulist>',
+                        help='monitor for given cpus only (experimental)'
+                        if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '--refresh_stat', metavar='<milliseconds>', action='append',
             help='automatic kdamond internal stat refresh interval')
