@@ -510,6 +510,19 @@ def write_monitoring_intervals_goal_dir(dir_path, goal):
     if err is not None:
         return err
 
+def write_ops_attrs_dir(dir_path, ops_attrs):
+    if not os.path.isdir(dir_path):
+        return None
+    err = _damo_fs.write_file(os.path.join(dir_path, 'use_reports'),
+                               'Y' if ops_attrs.use_reports else 'N')
+    if err is not None:
+        return err
+    err = _damo_fs.write_file(os.path.join(dir_path, 'write_only'),
+                               'Y' if ops_attrs.write_only else 'N')
+    if err is not None:
+        return err
+    return _damo_fs.write_file(os.path.join(dir_path, 'cpus'), ops_attrs.cpus)
+
 def write_monitoring_attrs_dir(dir_path, context):
     err = _damo_fs.write_file(
             os.path.join(dir_path, 'intervals', 'sample_us'),
@@ -552,6 +565,11 @@ def write_context_dir(dir_path, context):
     if err is not None:
         return err
 
+    err = write_ops_attrs_dir(
+            os.path.join(dir_path, 'operations_attrs'), context.ops_attrs)
+    if err is not None:
+        return err
+
     err = write_monitoring_attrs_dir(
             os.path.join(dir_path, 'monitoring_attrs'), context)
     if err is not None:
@@ -614,6 +632,29 @@ def stage_kdamonds(kdamonds):
     # Assume caller checked supported()
     return write_kdamonds_dir(get_kdamonds_dir(), kdamonds)
 
+def stage_kdamonds_targets(kdamonds):
+    kdamonds_dir_path = get_kdamonds_dir()
+
+    err = ensure_nr_file_for(os.path.join(kdamonds_dir_path, 'nr_kdamonds'), kdamonds)
+    if err:
+        return err
+
+    for k_idx, kdamond in enumerate(kdamonds):
+        contexts_dir_path = os.path.join(kdamonds_dir_path, '%d' % k_idx, 'contexts')
+        contexts = kdamond.contexts
+
+        err = ensure_nr_file_for(os.path.join(contexts_dir_path, 'nr_contexts'), contexts)
+        if err:
+            return err
+
+        for c_idx, context in enumerate(contexts):
+            targets_dir_path = os.path.join(contexts_dir_path, '%d' % c_idx, 'targets')
+            err = write_targets_dir(targets_dir_path, context.targets)
+            if err:
+                return err
+
+    return None
+
 # for current_kdamonds()
 
 def numbered_dirs_content(files_content, nr_filename):
@@ -787,6 +828,13 @@ def files_content_to_target(files_content):
     regions = files_content_to_regions(files_content['regions'])
     return _damon.DamonTarget(pid, regions)
 
+def files_content_to_ops_attrs(files_content):
+    use_reports = files_content['use_reports'].strip()
+    write_only = files_content['write_only'].strip()
+    cpus = files_content['cpus'].strip()
+    return _damon.OpsAttrs(use_reports=use_reports, write_only=write_only,
+                           cpus=cpus)
+
 def files_content_to_context(files_content):
     mon_attrs_content = files_content['monitoring_attrs']
     intervals_content = mon_attrs_content['intervals']
@@ -807,6 +855,11 @@ def files_content_to_context(files_content):
             int(nr_regions_content['min']),
             int(nr_regions_content['max']))
     ops = files_content['operations'].strip()
+    if 'operations_attrs' in files_content:
+        ops_attrs = files_content_to_ops_attrs(
+                files_content['operations_attrs'])
+    else:
+        ops_attrs = _damon.OpsAttrs()
 
     targets_content = files_content['targets']
     targets = [files_content_to_target(content)
@@ -818,7 +871,8 @@ def files_content_to_context(files_content):
             for content in numbered_dirs_content(
                 schemes_content, 'nr_schemes')]
 
-    return _damon.DamonCtx(ops, targets, intervals, nr_regions, schemes)
+    return _damon.DamonCtx(ops, targets, intervals, nr_regions, schemes,
+                           ops_attrs=ops_attrs)
 
 def files_content_to_kdamond(files_content):
     contexts_content = files_content['contexts']
@@ -1109,6 +1163,9 @@ def update_supported_features():
     if os.path.isfile(os.path.join(kdamond_dir_of(0), 'refresh_ms')):
         feature_supports['sysfs_refresh_ms'] = True
 
+    if os.path.isdir(os.path.join(ctx_dir_of(0, 0), 'operations_attrs')):
+        feature_supports['ops_attrs'] = True
+
     avail_ops, err = _avail_ops()
     if err == None:
         for ops in ['vaddr', 'paddr', 'fvaddr']:
